@@ -1,5 +1,6 @@
 """ Contains an object to describe a spectrum, and various
 spectrum-related functions."""
+from __future__ import division
 
 from itertools import izip
 import copy
@@ -1230,8 +1231,7 @@ def air2vac_Morton(airw):
     Only valid for wa > 2000 Angstroms.
     """
     airw = np.atleast_1d(airw)
-    if (np.diff(airw) < 0).any():
-        raise ValueError('Wavelengths must be sorted lowest to highest')
+    if (np.diff(airw) < 0).any():        raise ValueError('Wavelengths must be sorted lowest to highest')
     if airw[0] < 2000:
         raise ValueError('Only valid for wavelengths > 2000 Angstroms')
     dwmax = abs(vac2air_Morton(airw[-1]) - airw[-1]) + 10
@@ -1268,73 +1268,3 @@ def air2vac_Ciddor(airw):
     if len(vacw) == 1:
         return vacw[0]
     return vacw
-
-def qso_template(wa, z):
-    """ Return a composite visible QSO spectrum at redshift z.
-
-    The SDSS composite spectrum as a function of F_lambda is returned
-    at each wavelength of wa. wa must be in angstroms.
-    """
-    r = readtabfits(DATAPATH + '/templates/qso/dr1QSOspec.fits')
-    return np.interp(wa, r.wa*(1 + z), r.fl)
-
-def qso_template_uv(wa, z, smooth_fwhmpix=6):
-    """ Return a composite UV QSO spectrum at redshift z.
-
-    Wavelengths must be in Angstroms.
-    """
-    w, f, e = np.loadtxt(DATAPATH + 'templates/qso/telfer_composite_qso.txt',
-                         unpack=1)
-    fl = np.interp(wa, w*(1 + z), f)
-    fl = convolve_psf(fl, smooth_fwhmpix)
-    return fl
-
-def make_constant_dv_wa_scale(wmin, wmax, dv):
-    """ Make a constant velocity width scale given a start and end
-    wavelength, and velocity pixel width.
-    """
-    dlogw = np.log10(1 + dv/c_kms)
-    # find the number of points needed.
-    npts = int(np.log10(wmax / wmin) / dlogw)
-    wa = wmin * 10**(np.arange(npts)*dlogw)
-    return wa
-
-def convolve_constant_dv(wa, fl, wa_dv=None, npix=4., vfwhm=None):
-    """ Convolve a wavelength array with a gaussian of constant
-    velocity width.
-
-    If `vfwhm` is specified an intermediate wavelength array with
-    constant velocity pixel width is calculated. Otherwise, both
-    `wa_dv` and `npix` must be given -- this is faster because no
-    intermediate array needs to be calculated.
-
-    Parameters
-    ----------
-    fl, wa : arrays of floats, length N
-      The array to be convolved and its wavelengths.
-    vfwhm : float, optional
-      Full width at half maximum in velocity space (km/s) of the
-      gaussian kernel with which to convolve `fl`.
-    npix : float, default 4
-      Number of pixels corresponding to `vfwhm` in `wa_dv` if given,
-      otherwise `wa` is interpolated to an array with velocity pixel
-      width = vfwhm / npix.
-    wa_dv : array of floats, default `None`
-      Wavelength array with a constant velocity width (this can be
-      generated with make_constant_dv_wa_scale()).
-
-    Returns
-    -------
-    fl_out : array of length N
-      fl convolved with the gaussian kernel with the specified FWHM.
-     
-    """
-    # interpolate to the log-linear scale, convolve, then
-    # interpolate back again.
-    # convolve with the gaussian
-    if vfwhm is not None:
-        wa_dv = make_constant_dv_wa_scale(wa[0], wa[-1], float(vfwhm)/npix)
-    fl_dv = np.interp(wa_dv, wa, fl)
-    fl_dv_smoothed = convolve_psf(fl_dv, npix)
-    fl_out = np.interp(wa, wa_dv, fl_dv_smoothed)
-    return fl_out
