@@ -1,4 +1,5 @@
 from ..sed import *
+from ..constants import Jy, c
 import pylab as pl
 import numpy as np
 
@@ -22,4 +23,10 @@ def test_seds():
         tLBG_gmr.append(tLBG.calc_colour(sdss_g,sdss_r, 'AB'))
         tLBGa_umg.append(tLBGa.calc_colour(sdss_u,sdss_g, 'AB'))
         tLBGa_gmr.append(tLBGa.calc_colour(sdss_g,sdss_r, 'AB'))
-     
+
+
+def test_fnu_flambda():
+    wa = np.logspace(1, 10, 1e5)
+    fnu = 3631 * Jy
+    np.allclose(fnu_to_flambda(wa, fnu), 1e-8 * fnu / (wa * 1e-8)**2)
+    np.allclose(fnu, flambda_to_fnu(wa, fnu_to_flambda(wa, fnu)))
